============
Examples
============


.. toctree::
   :maxdepth: 1

   examples/introducing_the_girder_api.rst
   examples/procedure_for_typical_annotation_project.rst
   examples/tips_for_scalable_annotation_rendering.rst
   examples/annotation_database_backup_and_sql_parser.rst
   examples/creating_gallery_images_review.rst
   examples/using_large_image.ipynb
   examples/color_deconvolution.ipynb
   examples/color_normalization_and_augmentation.ipynb
   examples/nuclei_segmentation.ipynb
   examples/positive_pixel_count.ipynb
   examples/annotations_to_semantic_segmentation_masks.ipynb
   examples/annotations_to_object_segmentation_masks.ipynb
   examples/segmentation_masks_to_annotations.ipynb
   examples/polygon_merger_from_tiled_masks.ipynb
   examples/polygon_merger_using_rtree.ipynb
   examples/simple_tissue_detection.ipynb
   examples/semantic_segmentation_color_thresholding_approach.ipynb
   examples/semantic_segmentation_superpixel_approach.ipynb
   examples/workflows.ipynb
